@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,65 +15,28 @@
  * @category   Zend
  * @package    Zend_Auth
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AllTests.php 8402 2008-02-25 19:35:08Z darby $
+ * @version    $Id$
  */
 
-
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Auth_Adapter_AllTests::main');
 }
 
-
-/**
- * PHPUnit_Framework_TestSuite
- */
-require_once 'PHPUnit/Framework/TestSuite.php';
-
-
-/**
- * PHPUnit_TextUI_TestRunner
- */
-require_once 'PHPUnit/TextUI/TestRunner.php';
-
-
-/**
- * @see Zend_Auth_Adapter_DbTable_AllTests
- */
 require_once 'Zend/Auth/Adapter/DbTable/AllTests.php';
-
-
-/**
- * @see Zend_Auth_Adapter_DigestTest
- */
 require_once 'Zend/Auth/Adapter/DigestTest.php';
-
-
-/**
- * @see Zend_Auth_Adapter_Http_AllTests
- */
 require_once 'Zend/Auth/Adapter/Http/AllTests.php';
-
-
-/**
- * @see Zend_Auth_Adapter_Ldap_AllTests
- */
 require_once 'Zend/Auth/Adapter/Ldap/AllTests.php';
-
-
-/**
- * @see Zend_Auth_Adapter_OpenId_AllTests
- */
 require_once 'Zend/Auth/Adapter/OpenId/AllTests.php';
 
-
 /**
  * @category   Zend
  * @package    Zend_Auth
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Auth
  */
 class Zend_Auth_Adapter_AllTests
 {
@@ -95,7 +57,7 @@ class Zend_Auth_Adapter_AllTests
      */
     public static function suite()
     {
-        $suite = new PHPUnit_Framework_TestSuite('Zend Framework - Zend_Auth Adapters');
+        $suite = new PHPUnit_Framework_TestSuite('Zend Framework - Zend_Auth_Adapter');
 
         $suite->addTest(Zend_Auth_Adapter_DbTable_AllTests::suite());
         $suite->addTestSuite('Zend_Auth_Adapter_DigestTest');
