@@ -1,33 +1,48 @@
 <?php
-require_once 'PHPUnit/Util/Filter.php';
-
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
-
 /**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
+ * @category   Zend
  * @package    Zend_Cache
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id$
  */
 
-/**
- * PHPUnit test case
- */
-require_once 'PHPUnit/Framework/TestCase.php';
+
+
 
 /**
+ * @category   Zend
  * @package    Zend_Cache
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Cache
  */
-class Zend_Cache_CommonBackendTest extends PHPUnit_Framework_TestCase {
+abstract class Zend_Cache_CommonBackendTest extends PHPUnit_Framework_TestCase {
 
     protected $_instance;
     protected $_className;
     protected $_root;
 
-    public function __construct($className)
+    public function __construct($name = null, array $data = array(), $dataName = '')
     {
-        $this->_className = $className;
+        $this->_className = $name;
         $this->_root = dirname(__FILE__);
         date_default_timezone_set('UTC');
+        parent::__construct($name, $data, $dataName);
     }
 
     public function setUp($notag = false)
@@ -77,7 +92,9 @@ class Zend_Cache_CommonBackendTest extends PHPUnit_Framework_TestCase {
 
     public function tearDown()
     {
-        $this->_instance->clean();
+        if ($this->_instance) {
+            $this->_instance->clean();
+        }
         $this->rmdir();
     }
 
@@ -90,7 +107,7 @@ class Zend_Cache_CommonBackendTest extends PHPUnit_Framework_TestCase {
     {
         try {
             $class = $this->_className;
-            $test = new $class(array('foo' => 'bar'));
+            $test = new $class(array(1 => 'bar'));
         } catch (Zend_Cache_Exception $e) {
             return;
         }
@@ -214,6 +231,14 @@ class Zend_Cache_CommonBackendTest extends PHPUnit_Framework_TestCase {
 
     public function testCleanModeAll()
     {
+        if ($this instanceof Zend_Cache_MemcachedBackendTest
+            && getenv('TRAVIS')
+        ) {
+            $this->markTestSkipped(
+                'Test randomly fail on travis-ci.'
+            );
+        }
+
         $this->assertTrue($this->_instance->clean('all'));
         $this->assertFalse($this->_instance->test('bar'));
         $this->assertFalse($this->_instance->test('bar2'));
@@ -263,6 +288,11 @@ class Zend_Cache_CommonBackendTest extends PHPUnit_Framework_TestCase {
         $this->assertFalse($this->_instance->test('bar3'));
     }
 
+    public function testGetOption()
+    {
+        $this->assertTrue(is_numeric($this->_instance->getOption('LifeTime')));
+
+        $this->setExpectedException('Zend_Cache_Exception');
+        $this->_instance->getOption('unknown');
+    }
 }
-
-
