@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ContextSwitchTest.php 24864 2012-06-02 00:51:50Z adamlundrigan $
+ * @version    $Id$
  */
 
 // Call Zend_Controller_Action_Helper_ContextSwitchTest::main() if this source file is executed directly.
@@ -45,7 +45,7 @@ require_once 'Zend/View/Interface.php';
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Controller
  * @group      Zend_Controller_Action
@@ -478,20 +478,6 @@ class Zend_Controller_Action_Helper_ContextSwitchTest extends PHPUnit_Framework_
         $this->checkNothingIsDone();
     }
 
-    public function testInitContextThrowsExceptionIfControllerContextsIsInvalid()
-    {
-        $this->controller->contexts = 'foo';
-        $this->request->setParam('format', 'xml')
-                      ->setActionName('foo');
-        try {
-            $this->helper->initContext();
-            $this->fail('Invalid contexts array should cause failure');
-        } catch (Zend_Controller_Exception $e) {
-            $this->assertContains('Invalid', $e->getMessage());
-        }
-        $this->checkNothingIsDone();
-    }
-
     public function testInitContextDoesNothingIfActionHasNoContexts()
     {
         $this->request->setParam('format', 'xml')
