@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: Mysqli.php 6847 2007-11-18 05:24:21Z peptolab $
+ * @version    $Id$
  */
 
 
@@ -28,14 +27,14 @@
 require_once 'Zend/Db/TestUtil/Common.php';
 
 
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
+
 
 
 /**
  * @category   Zend
  * @package    Zend_Db
  * @subpackage Table
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Db_TestUtil_Mysqli extends Zend_Db_TestUtil_Common
@@ -90,6 +89,36 @@ class Zend_Db_TestUtil_Mysqli extends Zend_Db_TestUtil_Common
         }
     }
 
+    /**
+     * Test that describeTable() returns correct float type
+     * @group ZF-3624
+     */
+    protected function _getColumnsPrice()
+    {
+        return array(
+            'product_id'    => 'INTEGER NOT NULL',
+            'price_name'    => 'VARCHAR(100)',
+            'price'         => 'FLOAT(10,8)',
+            'price_total'   => 'DECIMAL(10,2) NOT NULL',
+            'PRIMARY KEY'   => 'product_id'
+            );
+    }
+
+    /**
+     * Test that describeTable() returns correct float type
+     * @group ZF-3624
+     */
+    protected function _getDataPrice()
+    {
+        return array(
+            array(
+                'product_id'   => 1,
+                'price_name'   => 'Price 1',
+                'price_total'  => 200.45
+            )
+        );
+    }
+
     public function setUp(Zend_Db_Adapter_Abstract $db)
     {
         parent::setUp($db);
@@ -106,12 +135,22 @@ class Zend_Db_TestUtil_Mysqli extends Zend_Db_TestUtil_Common
 
     protected function _createTestProcedure()
     {
-        $this->_rawQuery('DROP PROCEDURE IF EXISTS zf_test_procedure');
-        $this->_rawQuery('CREATE PROCEDURE zf_test_procedure(IN param1 INTEGER) BEGIN SELECT * FROM zfproducts WHERE product_id = param1; END');
+        $this->_tryRawQuery('DROP PROCEDURE IF EXISTS zf_test_procedure');
+        $this->_tryRawQuery('CREATE PROCEDURE zf_test_procedure(IN param1 INTEGER) BEGIN SELECT * FROM zfproducts WHERE product_id = param1; END');
     }
 
     protected function _dropTestProcedure()
     {
-        $this->_rawQuery('DROP PROCEDURE IF EXISTS zf_test_procedure');
+        $this->_tryRawQuery('DROP PROCEDURE IF EXISTS zf_test_procedure');
+    }
+
+    protected function _getSqlCreateView($viewName)
+    {
+        return 'CREATE OR REPLACE VIEW ' . $this->_db->quoteIdentifier($viewName, true);
+    }
+
+    protected function _getSqlDropView($viewName)
+    {
+        return 'DROP VIEW IF EXISTS ' . $this->_db->quoteIdentifier($viewName, true);
     }
 }
