@@ -15,17 +15,11 @@
  * @category   Zend
  * @package    Zend_Mail
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: MboxFolderTest.php 9276 2008-04-22 15:39:06Z nico $
+ * @version    $Id$
  */
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /**
  * @see Zend_Mail_Storage_Folder_Mbox
  */
@@ -41,8 +35,9 @@ require_once 'Zend/Config.php';
  * @category   Zend
  * @package    Zend_Mail
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Mail
  */
 class Zend_Mail_MboxFolderTest extends PHPUnit_Framework_TestCase
 {
@@ -166,7 +161,7 @@ class Zend_Mail_MboxFolderTest extends PHPUnit_Framework_TestCase
         $this->fail('no exception raised while loading unknown dirname');
     }
 
-    public function testLoadUnkownFolder()
+    public function testLoadUnknownFolder()
     {
         $this->_params['folder'] = 'UnknownFolder';
         try {
@@ -295,7 +290,7 @@ class Zend_Mail_MboxFolderTest extends PHPUnit_Framework_TestCase
         $mail = new Zend_Mail_Storage_Folder_Mbox($this->_params);
 
         $count = $mail->countMessages();
-        $this->assertEquals(6, $count);
+        $this->assertEquals(7, $count);
 
         $mail->selectFolder(DIRECTORY_SEPARATOR . 'subfolder' . DIRECTORY_SEPARATOR . 'test');
         $count = $mail->countMessages();
@@ -305,7 +300,7 @@ class Zend_Mail_MboxFolderTest extends PHPUnit_Framework_TestCase
     public function testSize()
     {
         $mail = new Zend_Mail_Storage_Folder_Mbox($this->_params);
-        $shouldSizes = array(1 => 397, 89, 694, 452, 497, 103);
+        $shouldSizes = array(1 => 397, 89, 694, 452, 497, 101, 139);
 
         $sizes = $mail->getSize();
         $this->assertEquals($shouldSizes, $sizes);
