@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,24 +15,19 @@
  * @category   Zend
  * @package    Zend_Service_Flickr
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: OnlineTest.php 8733 2008-03-10 15:56:48Z jokke $
+ * @version    $Id$
  */
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
-
 /**
  * @category   Zend
  * @package    Zend_Service_Flickr
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Service
+ * @group      Zend_Service_Flickr
  */
 class Zend_Service_Flickr_OnlineTest extends PHPUnit_Framework_TestCase
 {
@@ -74,7 +68,7 @@ class Zend_Service_Flickr_OnlineTest extends PHPUnit_Framework_TestCase
                       ->getHttpClient()
                       ->setAdapter($this->_httpClientAdapterSocket);
     }
-    
+
     /**
      * Basic testing to ensure that groupPoolGetPhotos works as expected
      *
@@ -85,16 +79,16 @@ class Zend_Service_Flickr_OnlineTest extends PHPUnit_Framework_TestCase
         $options = array('per_page' => 10,
                          'page'     => 1,
                          'extras'   => 'license, date_upload, date_taken, owner_name, icon_server');
-                         
+
         $resultSet = $this->_flickr->groupPoolGetPhotos('20083316@N00', $options);
-        
-        $this->assertEquals(21770, $resultSet->totalResultsAvailable);
+
+        $this->assertGreaterThan(20000, $resultSet->totalResultsAvailable);
         $this->assertEquals(10, $resultSet->totalResults());
         $this->assertEquals(10, $resultSet->totalResultsReturned);
         $this->assertEquals(1, $resultSet->firstResultPosition);
 
         $this->assertEquals(0, $resultSet->key());
-        
+
         try {
             $resultSet->seek(-1);
             $this->fail('Expected OutOfBoundsException not thrown');
@@ -210,13 +204,29 @@ class Zend_Service_Flickr_OnlineTest extends PHPUnit_Framework_TestCase
             $dateTakenPrevious = $result->datetaken;
         }
     }
+
+    /**
+     *  @see ZF-6397
+     */
+    function testTotalForEmptyResultSet()
+    {
+        $this->assertEquals(0, $this->_flickr->tagSearch('zendflickrtesttagnoresults')->totalResults());
+    }
 }
 
-
+/**
+ * @category   Zend
+ * @package    Zend_Service_Flickr
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Service
+ * @group      Zend_Service_Flickr
+ */
 class Zend_Service_Flickr_OnlineTest_Skip extends PHPUnit_Framework_TestCase
 {
     public function testNothing()
     {
         $this->markTestSkipped('Zend_Service_Flickr online tests not enabled in TestConfiguration.php');
     }
-}
\ No newline at end of file
+}
