@@ -13,19 +13,13 @@
  * to license@zend.com so we can send you a copy immediately.
  *
  * @category   Zend
- * @package    Zend_Service
+ * @package    Zend_Service_StrikeIron
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: DecoratorTest.php 8064 2008-02-16 10:58:39Z thomas $
+ * @version    $Id$
  */
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 /**
  * @see Zend_Service_StrikeIron_Decorator
  */
@@ -34,19 +28,21 @@ require_once 'Zend/Service/StrikeIron/Decorator.php';
 
 /**
  * @category   Zend
- * @package    Zend_Service
+ * @package    Zend_Service_StrikeIron
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Service
+ * @group      Zend_Service_StrikeIron
  */
-class Zend_Service_StrikeIron_DecoratorTest extends PHPUnit_Framework_TestCase 
+class Zend_Service_StrikeIron_DecoratorTest extends PHPUnit_Framework_TestCase
 {
     public function testNoNoticesWhenDecoratedObjectIsNotAnObject()
     {
         $decorator = new Zend_Service_StrikeIron_Decorator(3.1415);
         $this->assertSame(null, $decorator->foo);
     }
-    
+
     public function testDecoratorReturnsNullWhenPropertyIsMissing()
     {
         $object = new stdclass();
@@ -61,7 +57,7 @@ class Zend_Service_StrikeIron_DecoratorTest extends PHPUnit_Framework_TestCase
         $decorator = new Zend_Service_StrikeIron_Decorator($object);
         $this->assertEquals('qux', $decorator->Baz);
     }
-    
+
     public function testDecoratorReturnsPropertyByInflectedName()
     {
         $object = (object)array('Foo' => 'bar',
@@ -69,7 +65,7 @@ class Zend_Service_StrikeIron_DecoratorTest extends PHPUnit_Framework_TestCase
         $decorator = new Zend_Service_StrikeIron_Decorator($object);
         $this->assertEquals('qux', $decorator->baz);
     }
-    
+
     public function testDecoratorTriesActualPropertyNameBeforeInflecting()
     {
         $object = (object)array('foo' => 'bar',
@@ -77,12 +73,13 @@ class Zend_Service_StrikeIron_DecoratorTest extends PHPUnit_Framework_TestCase
         $decorator = new Zend_Service_StrikeIron_Decorator($object);
         $this->assertEquals('bar', $decorator->foo);
     }
-    
+
     public function testDecoratorReturnsAnotherDecoratorWhenValueIsAnObject()
     {
         $object = (object)array('Foo' => new stdclass);
         $decorator = new Zend_Service_StrikeIron_Decorator($object);
-        $this->assertType(get_class($decorator), $decorator->Foo);
+        $class = get_class($decorator);
+        $this->assertTrue($decorator->Foo instanceof $class);
     }
 
     public function testDecoratorProxiesMethodCalls()
@@ -90,12 +87,12 @@ class Zend_Service_StrikeIron_DecoratorTest extends PHPUnit_Framework_TestCase
         $decorator = new Zend_Service_StrikeIron_Decorator($this);
         $this->assertEquals('bar', $decorator->foo());
     }
-    
+
     public function foo()
     {
         return 'bar';
     }
-    
+
     public function testGettingTheDecoratedObject()
     {
         $decorator = new Zend_Service_StrikeIron_Decorator($this);
@@ -107,4 +104,4 @@ class Zend_Service_StrikeIron_DecoratorTest extends PHPUnit_Framework_TestCase
         $decorator = new Zend_Service_StrikeIron_Decorator($this, 'foo');
         $this->assertSame('foo', $decorator->getDecoratedObjectName());
     }
-}
\ No newline at end of file
+}
