@@ -13,19 +13,14 @@
  * to license@zend.com so we can send you a copy immediately.
  *
  * @category   Zend
- * @package    Zend_Service
+ * @package    Zend_Service_StrikeIron
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: NoSoapTest.php 8064 2008-02-16 10:58:39Z thomas $
+ * @version    $Id$
  */
 
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 /**
  * @see Zend_Service_StrikeIron_BaseTest
  */
@@ -34,12 +29,14 @@ require_once 'Zend/Service/StrikeIron/BaseTest.php';
 
 /**
  * @category   Zend
- * @package    Zend_Service
+ * @package    Zend_Service_StrikeIron
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Service
+ * @group      Zend_Service_StrikeIron
  */
-class Zend_Service_StrikeIron_NoSoapTest extends PHPUnit_Framework_TestCase 
+class Zend_Service_StrikeIron_NoSoapTest extends PHPUnit_Framework_TestCase
 {
 
     public function setUp()
@@ -49,7 +46,7 @@ class Zend_Service_StrikeIron_NoSoapTest extends PHPUnit_Framework_TestCase
             $this->markTestSkipped('SOAP extension is loaded, so cannot test for exception');
         }
     }
-    
+
     public function testNoSoapException()
     {
         try {
@@ -58,7 +55,7 @@ class Zend_Service_StrikeIron_NoSoapTest extends PHPUnit_Framework_TestCase
                                                              'password' => 'pass'));
             $this->fail('Expecting exception of type Zend_Service_StrikeIron_Exception');
         } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Service_StrikeIron_Exception', $e,
+            $this->assertTrue($e instanceof Zend_Service_StrikeIron_Exception,
                 'Expecting exception of type Zend_Service_StrikeIron_Exception, got '.get_class($e));
             $this->assertEquals('SOAP extension is not enabled', $e->getMessage());
         }
