@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Service_Technorati
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: UtilsTest.php 24593 2012-01-05 20:35:02Z matthew $
+ * @version    $Id$
  */
 
 
@@ -36,7 +36,7 @@ require_once "Zend/Service/Technorati/Utils.php";
  * @category   Zend
  * @package    Zend_Service_Technorati
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Service
  * @group      Zend_Service_Technorati
@@ -82,7 +82,7 @@ class Zend_Service_Technorati_UtilsTest extends Zend_Service_Technorati_TestCase
         $date   = new Zend_Date('2007-11-11 08:47:26 GMT');
         $result = Zend_Service_Technorati_Utils::normalizeDate($date);
 
-        $this->assertType('Zend_Date', $result);
+        $this->assertTrue($result instanceof Zend_Date);
         $this->assertEquals($date, $result);
     }
 
