@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,29 +15,23 @@
  * @category   Zend
  * @package    Zend_Validate
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: DateTest.php 11179 2008-09-01 09:25:19Z alexander $
+ * @version    $Id$
  */
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /**
  * @see Zend_Validate_Date
  */
 require_once 'Zend/Validate/Date.php';
 
-
 /**
  * @category   Zend
  * @package    Zend_Validate
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Validate
  */
 class Zend_Validate_DateTest extends PHPUnit_Framework_TestCase
 {
@@ -96,7 +89,7 @@ class Zend_Validate_DateTest extends PHPUnit_Framework_TestCase
     /**
      * Ensures that characters trailing an otherwise valid date cause the input to be invalid
      *
-     * @see    http://framework.zend.com/issues/browse/ZF-1804
+     * @group ZF-1804
      * @return void
      */
     public function testCharactersTrailingInvalid()
@@ -110,7 +103,7 @@ class Zend_Validate_DateTest extends PHPUnit_Framework_TestCase
     /**
      * Ensures that characters leading an otherwise valid date cause the input to be invalid
      *
-     * @see    http://framework.zend.com/issues/browse/ZF-1804
+     * @group ZF-1804
      * @return void
      */
     public function testCharactersLeadingInvalid()
@@ -134,14 +127,18 @@ class Zend_Validate_DateTest extends PHPUnit_Framework_TestCase
     /**
      * Ensures that the validator can handle different manual dateformats
      *
-     * @see    http://framework.zend.com/issues/browse/ZF-2003
+     * @group ZF-2003
      * @return void
      */
     public function testUseManualFormat()
     {
         $this->assertTrue($this->_validator->setFormat('dd.MM.YYYY')->isValid('10.01.2008'));
-        $this->assertTrue($this->_validator->setFormat('MMM yyyy')->isValid('Jan 2010'));
+        $this->assertEquals('dd.MM.YYYY', $this->_validator->getFormat());
+
+        $this->assertTrue($this->_validator->setFormat('MM yyyy')->isValid('01 2010'));
         $this->assertFalse($this->_validator->setFormat('dd/MM/yyyy')->isValid('2008/10/22'));
+        $this->assertTrue($this->_validator->setFormat('dd/MM/yy')->isValid('22/10/08'));
+        $this->assertFalse($this->_validator->setFormat('dd/MM/yy')->isValid('22/10'));
         set_error_handler(array($this, 'errorHandlerIgnore'));
         $result = $this->_validator->setFormat('s')->isValid(0);
         restore_error_handler();
@@ -156,7 +153,7 @@ class Zend_Validate_DateTest extends PHPUnit_Framework_TestCase
     /**
      * Ensures that the validator can handle different dateformats from locale
      *
-     * @see    http://framework.zend.com/issues/browse/ZF-2003
+     * @group ZF-2003
      * @return void
      */
     public function testUseLocaleFormat()
@@ -167,7 +164,7 @@ class Zend_Validate_DateTest extends PHPUnit_Framework_TestCase
             '10.01.2008' => true,
             '32.02.2008' => false,
             '20 April 2008' => true,
-            '1 Jul 2008' => true,
+            '1.Juli.2008' => true,
             '2008/20/03' => false,
             '99/99/2000' => false,
             0            => false,
@@ -184,12 +181,65 @@ class Zend_Validate_DateTest extends PHPUnit_Framework_TestCase
             }
             $this->_errorOccurred = false;
         }
+        $this->assertEquals('de_AT', $this->_validator->getLocale());
         restore_error_handler();
         if ($errorOccurredLocal) {
             $this->markTestSkipped('Affected by bug described in ZF-2789');
         }
     }
 
+    /**
+     * Ensures that the validator can handle different dateformats from locale
+     *
+     * @group ZF-2003
+     * @return void
+     */
+    public function testLocaleContructor()
+    {
+        set_error_handler(array($this, 'errorHandlerIgnore'));
+        $valid = new Zend_Validate_Date('dd.MM.YYYY', 'de');
+        $this->assertTrue($valid->isValid('10.April.2008'));
+
+        restore_error_handler();
+    }
+
+    /**
+     * @ZF-4352
+     */
+    public function testNonStringValidation()
+    {
+        $this->assertFalse($this->_validator->isValid(array(1 => 1)));
+    }
+
+    /**
+     * @ZF-6374
+     */
+    public function testUsingApplicationLocale()
+    {
+        Zend_Registry::set('Zend_Locale', new Zend_Locale('de'));
+        $valid = new Zend_Validate_Date();
+        $this->assertTrue($valid->isValid('10.April.2008'));
+    }
+
+    /**
+     * ZF-7630
+     */
+    public function testDateObjectVerification()
+    {
+        $date = new Zend_Date();
+        $this->assertTrue($this->_validator->isValid($date), "'$date' expected to be valid");
+    }
+
+    /**
+     * ZF-6457
+     */
+    public function testArrayVerification()
+    {
+        $date  = new Zend_Date();
+        $array = $date->toArray();
+        $this->assertTrue($this->_validator->isValid($array), "array expected to be valid");
+    }
+
     /**
      * Ignores a raised PHP error when in effect, but throws a flag to indicate an error occurred
      *
@@ -199,7 +249,7 @@ class Zend_Validate_DateTest extends PHPUnit_Framework_TestCase
      * @param  integer $errline
      * @param  array   $errcontext
      * @return void
-     * @see    http://framework.zend.com/issues/browse/ZF-2789
+     * @group ZF-2789
      */
     public function errorHandlerIgnore($errno, $errstr, $errfile, $errline, array $errcontext)
     {
