@@ -15,7 +15,7 @@
  * @category   Zend
  * @package    Zend_Validate
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @version    $Id$
  */
@@ -30,7 +30,7 @@ require_once 'Zend/Validate/Hostname.php';
  * @category   Zend
  * @package    Zend_Validate
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Validate
  */
@@ -50,7 +50,9 @@ class Zend_Validate_HostnameTest extends PHPUnit_Framework_TestCase
      */
     public function setUp()
     {
-        $this->_origEncoding = iconv_get_encoding('internal_encoding');
+        $this->_origEncoding = PHP_VERSION_ID < 50600
+                    ? iconv_get_encoding('internal_encoding')
+                    : ini_get('default_charset');
         $this->_validator = new Zend_Validate_Hostname();
     }
 
@@ -59,7 +61,11 @@ class Zend_Validate_HostnameTest extends PHPUnit_Framework_TestCase
      */
     public function tearDown()
     {
-        iconv_set_encoding('internal_encoding', $this->_origEncoding);
+        if (PHP_VERSION_ID < 50600) {
+            iconv_set_encoding('internal_encoding', $this->_origEncoding);
+        } else {
+            ini_set('default_charset', $this->_origEncoding);
+        }
     }
 
     /**
@@ -228,7 +234,7 @@ class Zend_Validate_HostnameTest extends PHPUnit_Framework_TestCase
 
         // Check TLD matching
         $valuesExpected = array(
-            array(true, array('domain.co.uk', 'domain.uk.com', 'domain.tl', 'domain.zw', 'domain.menu')),
+            array(true, array('domain.co.uk', 'domain.uk.com', 'domain.tl', 'domain.zw', 'domain.menu', 'domain.versicherung')),
             array(false, array('domain.xx', 'domain.zz', 'domain.madeup'))
             );
         foreach ($valuesExpected as $element) {
@@ -328,7 +334,7 @@ class Zend_Validate_HostnameTest extends PHPUnit_Framework_TestCase
 
         // Check TLD matching
         $valuesExpected = array(
-            array(true, array('xn--brger-kva.com')),
+            array(true, array('xn--brger-kva.com', 'xn--eckwd4c7cu47r2wf.jp')),
             array(false, array('xn--brger-x45d2va.com', 'xn--bürger.com', 'xn--'))
             );
         foreach ($valuesExpected as $element) {
@@ -361,7 +367,11 @@ class Zend_Validate_HostnameTest extends PHPUnit_Framework_TestCase
      */
     public function testDifferentIconvEncoding()
     {
-        iconv_set_encoding('internal_encoding', 'ISO8859-1');
+        if (PHP_VERSION_ID < 50600) {
+            iconv_set_encoding('internal_encoding', 'ISO8859-1');
+        } else {
+            ini_set('default_charset', 'ISO8859-1');
+        }
         $validator = new Zend_Validate_Hostname();
 
         $valuesExpected = array(
@@ -498,4 +508,23 @@ class Zend_Validate_HostnameTest extends PHPUnit_Framework_TestCase
 
         $this->assertTrue($validator->isValid('test.rs'));
     }
+
+    /**
+     * @group GH-19
+     */
+    public function testRussianIdn()
+    {
+        $validator = new Zend_Validate_Hostname();
+        $this->assertTrue($validator->isValid('кц.рф'));
+        $this->assertTrue($validator->isValid('президент.рф'));
+    }
+
+    /**
+     * @group GH-451
+     */
+    public function testVermögensberaterIdns()
+    {
+        $validator = new Zend_Validate_Hostname();
+        $this->assertTrue($validator->isValid('mysite.vermögensberater'));
+    }
 }
